//
//  PrintSinglePageRenderer.m
//  printTest
//
//  Created by Y on 11/03/06.
//  Copyright 2011 京都産業大学. All rights reserved.
//

#import "PrintSinglePageRenderer.h"


@implementation PrintSinglePageRenderer

@synthesize imageToPrint;

// This code always draws one image at print time.
-(NSInteger)numberOfPages
{
	return 1; // 1 page 限定なのでこう答える
}

// コンテント（実はページ全域への）描画
-(void)drawPageAtIndex:(NSInteger)pageIndex inRect:(CGRect)pageRect
{
	if(self.imageToPrint){
		CGRect destRect;
		CGSize imageSize = [self.imageToPrint size];
				 
		 // 紙サイズと出力可能サイズを比較して、
		 // 同一だったら fillSheet=YES として、出力時には紙の端まで出して周辺はクリップする。
		 // 同一でなければ（出力可能エリアが狭い場合は）はみ出さずに余白を入れる方向で調整する。
		CGSize paperSize = self.paperRect.size;
		CGSize imageableAreaSize = pageRect.size;
		BOOL fillSheet = paperSize.width == imageableAreaSize.width && paperSize.height == imageableAreaSize.height;
		 
		if(fillSheet){ // クリップする＝紙サイズの最大領域
			destRect = CGRectMake(0, 0, paperSize.width, paperSize.height);
		} else { // 余白を入れる＝pageRect を使う
			destRect = pageRect;
		}
		
		// 縦横のスケール値を得る
		CGFloat width_scale = (CGFloat)destRect.size.width/imageSize.width;
		CGFloat height_scale = (CGFloat)destRect.size.height/imageSize.height;
		 
		CGFloat scale;
		if(fillSheet) { // クリップする場合は縦横のスケール比の大きい方を取る
			scale = width_scale > height_scale ? width_scale : height_scale;
		} else { // 余白を出す場合は縦横のスケール比の小さい方を取る
			scale = width_scale < height_scale ? width_scale : height_scale;
		}
		
		// Locate destRect so that the scaled image is centered on the sheet. 
		destRect = CGRectMake((paperSize.width - imageSize.width*scale) / 2.0,
							  (paperSize.height - imageSize.height*scale) / 2.0, 
							  imageSize.width*scale, imageSize.height*scale);
		// 描画は対象が UIImage なので便利なメソッドがある
		[self.imageToPrint drawInRect:destRect];
		
	} else {
		NSLog(@"%s No image to draw!", __func__);
	}
}



@end
